<?php
/**
 * Plugin FAQ Parser
 * 
 * @package    Plugin FAQ Parser
 * @subpackage PluginFaqParserAdmin Management screen
    Copyright (c) 2016- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class PluginFaqParserAdmin {

	/* ==================================================
	 * Add a "Settings" link to the plugins page
	 * @since	1.0
	 */
	function settings_link($links, $file) {
		static $this_plugin;
		if ( empty($this_plugin) ) {
			$this_plugin = PLUGINFAQPARSER_PLUGIN_BASE_FILE;
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="'.admin_url('options-general.php?page=PluginFaqParser').'">'.__( 'Settings').'</a>';
		}
		return $links;
	}

	/* ==================================================
	 * Settings page
	 * @since	1.0
	 */
	function plugin_menu() {
		add_options_page( 'PluginFaqParser Options', 'Plugin FAQ Parser', 'manage_options', 'PluginFaqParser', array($this, 'plugin_options') );
	}

	/* ==================================================
	 * Add Css and Script
	 * @since	1.0
	 */
	function load_custom_wp_admin_style() {
		if ($this->is_my_plugin_screen()) {
			wp_enqueue_style( 'jquery-responsiveTabs', PLUGINFAQPARSER_PLUGIN_URL.'/css/responsive-tabs.css' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', PLUGINFAQPARSER_PLUGIN_URL.'/css/style.css' );
			wp_enqueue_script('jquery');
			wp_enqueue_script( 'jquery-responsiveTabs', PLUGINFAQPARSER_PLUGIN_URL.'/js/jquery.responsiveTabs.min.js' );
			wp_enqueue_script( 'pluginfaqparser-admin-js', PLUGINFAQPARSER_PLUGIN_URL.'/js/jquery.pluginfaqparser.admin.js', array('jquery') );
		}
	}

	/* ==================================================
	 * For only admin style
	 * @since	1.0
	 */
	function is_my_plugin_screen() {
		$screen = get_current_screen();
		if (is_object($screen) && $screen->id == 'settings_page_PluginFaqParser') {
			return TRUE;
		} else {
			return FALSE;
		}
	}

	/* ==================================================
	 * Settings page
	 * @since	1.0
	 */
	function plugin_options() {

		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}

		if( !empty($_POST) ) {
			$post_nonce_field = 'pluginfaqparser_tabs';
			if ( isset($_POST[$post_nonce_field]) && $_POST[$post_nonce_field] ) {
				if ( check_admin_referer( 'pfq_settings', $post_nonce_field ) ) {
					$this->options_updated();
				}
			}
		}

		$scriptname = admin_url('options-general.php?page=PluginFaqParser');

		?>
		<div class="wrap">
			<h2>PluginFaqParser</h2>
			<div id="pluginfaqparser-tabs">
				<ul>
				<li><a href="#pluginfaqparser-tabs-1"><?php _e('How to use', 'plugin-faq-parser'); ?></a></li>
				<li><a href="#pluginfaqparser-tabs-2"><?php _e('Donate to this plugin &#187;'); ?></a></li>
				<!--
				<li><a href="#pluginfaqparser-tabs-3">FAQ</a></li>
				 -->
				</ul>
				<div id="pluginfaqparser-tabs-1">
					<div class="wrap">
						<h2><?php _e('How to use', 'plugin-faq-parser'); ?></h2>
						<div style="padding:10px;"><?php _e('Please add new Page. Please write a short code in the text field of the Page. Please go in Text mode this task.', 'plugin-faq-parser'); ?></div>

						<div style="padding:10px;">
						<h3><?php _e('Example of short code',  'plugin-faq-parser'); ?></h3>

						<div style="padding: 10px 0px;"><code>[pluginfaq slug="media-from-ftp"]</code></div>
						<div style="padding: 10px 0px;"><code>[pluginfaq slug="media-from-ftp" theme="smoothness"]</code></div>

						<h3><?php _e('Description of each attribute' ,'plugin-faq-parser'); ?></h3>

						<li style="margin:10px;"><code>slug</code> <?php _e('Specifies the plugin slug.', 'plugin-faq-parser'); ?></li>
						<li style="margin:10px;"><code>theme</code> <?php _e('jQuery UI accordion is available. Please specify the following themes.', 'plugin-faq-parser'); ?><div>black-tie&nbsp;&nbsp;blitzer&nbsp;&nbsp;cupertino&nbsp;&nbsp;dark-hive&nbsp;&nbsp;dot-luv&nbsp;&nbsp;eggplan&nbsp;&nbsp;texcite-bike&nbsp;&nbsp;flick&nbsp;&nbsp;hot-sneaks&nbsp;&nbsp;humanity&nbsp;&nbsp;le-frog&nbsp;&nbsp;mint-choc&nbsp;&nbsp;overcast&nbsp;&nbsp;pepper-grinder&nbsp;&nbsp;redmond&nbsp;&nbsp;smoothness&nbsp;&nbsp;south-street&nbsp;&nbsp;start&nbsp;&nbsp;sunny&nbsp;&nbsp;swanky-purse&nbsp;&nbsp;trontastic&nbsp;&nbsp;ui-darkness&nbsp;&nbsp;ui-lightness&nbsp;&nbsp;vader</div><?php _e('Default'); ?>: <code>theme=NULL</code></li>

						<h3><?php _e('It will create a cache in one-day intervals for speedup. Please delete the cache if you want to display the most recent data.', 'plugin-faq-parser'); ?></h3>

						<form style="padding:10px;" method="post" action="<?php echo $scriptname; ?>" />
						<?php wp_nonce_field('pfq_settings', 'pluginfaqparser_tabs'); ?>
							<input type="hidden" name="pluginfaq_clear_cash" value="1" />
							<?php submit_button( __('Remove Cache', 'plugin-faq-parser'), 'large', 'Submit', FALSE ); ?>
						</form>

						</div>

					</div>
				</div>

				<div id="pluginfaqparser-tabs-2">
				<div class="wrap">
					<?php
					$plugin_datas = get_file_data( PLUGINFAQPARSER_PLUGIN_BASE_DIR.'/pluginfaqparser.php', array('version' => 'Version') );
					$plugin_version = __('Version:').' '.$plugin_datas['version'];
					?>
					<h4 style="margin: 5px; padding: 5px;">
					<?php echo $plugin_version; ?> |
					<a style="text-decoration: none;" href="https://wordpress.org/support/plugin/plugin-faq-parser" target="_blank"><?php _e('Support Forums') ?></a> |
					<a style="text-decoration: none;" href="https://wordpress.org/support/view/plugin-reviews/plugin-faq-parser" target="_blank"><?php _e('Reviews', 'plugin-faq-parser') ?></a>
					</h4>
					<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
					<h3><?php _e('Please make a donation if you like my work or would like to further the development of this plugin.', 'plugin-faq-parser'); ?></h3>
					<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
			<a style="margin: 5px; padding: 5px;" href='https://pledgie.com/campaigns/28307' target="_blank"><img alt='Click here to lend your support to: Various Plugins for WordPress and make a donation at pledgie.com !' src='https://pledgie.com/campaigns/28307.png?skin_name=chrome' border='0' ></a>
					</div>
				</div>
				</div>

			</div>
		</div>
		<?php
	}

	/* ==================================================
	 * Update wp_options table.
	 * @param	none
	 * @since	1.0
	 */
	function options_updated(){

		include_once PLUGINFAQPARSER_PLUGIN_BASE_DIR.'/inc/PluginFaqParser.php';
		$pluginfaqparser = new PluginFaqParser();
		if ( !empty($_POST['pluginfaq_clear_cash']) ) {
			$del_cash_count = $pluginfaqparser->delete_all_cash();
			if ( $del_cash_count > 0 ) {
				echo '<div class="notice notice-success is-dismissible"><ul><li>'.__('Removed the cache.', 'plugin-faq-parser').'</li></ul></div>';
			} else {
				echo '<div class="notice notice-error is-dismissible"><ul><li>'.__('No Cache', 'plugin-faq-parser').'</li></ul></div>';
			}
		}
		unset($pluginfaqparser);

	}

}

?>